@@ -1,4 +1,4 @@
-/* Copyright (C) 2022-2024 Free Software Foundation
+/* Copyright (C) 2022-2025 Free Software Foundation
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -821,11 +821,11 @@ public class AnChooser extends JFileChooser implements PropertyChangeListener {
     public String getDescription() {
       switch (chooser_type) {
         case EXP_GROUP_CHOOSER:
-          return AnLocale.getString("Analyzer Experiment Group (*.erg)");
+          return AnLocale.getString("gprofng experiment group (*.erg)");
         case TARGET_CHOOSER:
-          return AnLocale.getString("Analyzer Target (executable files)");
+          return AnLocale.getString("gprofng target (executable files)");
         default: // EXP_CHOOSER
-          return AnLocale.getString("Analyzer Experiment (*.er, *.erg)");
+          return AnLocale.getString("gprofng experiment (*.er, *.erg)");
       }
     }
   }
@@ -836,22 +836,20 @@ public class AnChooser extends JFileChooser implements PropertyChangeListener {
     @Override
     public Icon getIcon(final File file) {
       if (chooser_type == TARGET_CHOOSER) {
-        if (!file.isFile()) {
-          return getExperimentIcon(file);
-        }
         switch (AnUtility.getMimeFormat(file)) {
+          case AnUtility.MIME_DIRECTORY:
+            return getExperimentIcon(file);
           case AnUtility.MIME_ELF_EXECUTABLE:
+          case AnUtility.MIME_EXECUTABLE:
             return AnUtility.elf_icon;
           case AnUtility.MIME_JAVA_CLASS_FILE:
             return AnUtility.cls_icon;
           case AnUtility.MIME_JAR_FILE:
             return AnUtility.jar_icon;
-          default:
-            return getExperimentIcon(file);
         }
-      } else {
-        return getExperimentIcon(file);
+        return null;
       }
+      return getExperimentIcon(file);
     }
 
     private Icon getExperimentIcon(final File file) {
