@@ -1,4 +1,4 @@
-/* Copyright (C) 2022-2024 Free Software Foundation
+/* Copyright (C) 2022-2025 Free Software Foundation
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -29,9 +29,6 @@ import org.gprofng.mpmt.ipc.IPCContext;
 import org.gprofng.mpmt.mainview.Subview;
 import org.gprofng.mpmt.util.gui.AnUtility;
 import java.awt.Component;
-import java.awt.Toolkit;
-import java.awt.datatransfer.Clipboard;
-import java.awt.datatransfer.StringSelection;
 import java.util.ArrayList;
 import java.util.List;
 import javax.accessibility.AccessibleContext;
@@ -106,12 +103,6 @@ public abstract class AnDisplay extends JPanel {
     return null;
   }
 
-  protected void copyToClipboard(String text) {
-    StringSelection data = new StringSelection(text);
-    Clipboard clipboard = Toolkit.getDefaultToolkit().getSystemClipboard();
-    clipboard.setContents(data, data);
-  }
-
   //    abstract JPopupMenu getFilterPopup();
   public void showFilterPopup(Component parent) {
     JPopupMenu popup;
