@@ -1,4 +1,4 @@
-/* Copyright (C) 2022-2024 Free Software Foundation
+/* Copyright (C) 2022-2025 Free Software Foundation
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -26,8 +26,6 @@ import org.gprofng.mpmt.ipc.IPCResult;
 import org.gprofng.mpmt.metrics.MetricColors;
 import org.gprofng.mpmt.metrics.MetricColors.MetricColor;
 import org.gprofng.mpmt.persistence.UserPref;
-import org.gprofng.mpmt.persistence.UserPref.ConnectionProperties;
-import org.gprofng.mpmt.remote.Authentication;
 import org.gprofng.mpmt.remote.ConnectionDialog;
 import org.gprofng.mpmt.remote.ConnectionManager;
 import org.gprofng.mpmt.util.gui.AnUtility;
@@ -55,6 +53,8 @@ public final class Analyzer {
   public String os_name = null;
   public String er_print = null;
   public String localHost = null;
+  public String remoteConnectCommand = null; // For example, "ssh USER@HOST"
+  public String remoteGprofngPath = null;
   public String remoteConnection = null;
   public String remoteHost = null;
   public String remoteShell = "/usr/bin/ssh";
@@ -62,53 +62,16 @@ public final class Analyzer {
   public boolean normalSelection = false; // Right click changes selection
   public boolean IPC_started = false;
   public boolean connectingToRemoteHost = false; // true during the connecting process
-  public boolean connectingToRemoteHostEnabled = false;
+  public boolean connectingToRemoteHostEnabled = true;
   public boolean profileRunningProcessEnabled = false;
-  public Boolean kernelProfilingEnabled = null;
+  public boolean kernelProfilingEnabled = false;
   public boolean old_IPC_status = false;
   public int cur_id = 0;
   public static boolean compareMode = false;
 
   public static String fdversion, fdhome, licpath, licsts;
-  public IPC IPC_session;
+  public IPC IPC_session = null;
   public IPC old_IPC_session = null;
-  // the variables to control the availability of certain menus and toolbars
-  // these are default values for all IPC sessions
-  public static boolean m_is_open_exp_avail_default = true;
-  public static boolean m_is_aggregate_exp_avail_default = true;
-  public static boolean m_is_compare_exp_avail_default = true;
-  public static boolean m_is_print_dsp_avail_default = true;
-  public static boolean m_is_new_win_avail_default = true;
-  public static boolean m_is_close_act_avail_default = true;
-  public static boolean m_is_exit_act_avail_default = true;
-  public static boolean m_is_sel_present_avail_default = true;
-  public static boolean m_is_sel_filter_avail_default = true;
-  public static boolean m_is_show_hide_obj_avail_default = true;
-  public static boolean m_is_tbar_color_avail_default = true;
-  public static boolean m_is_find_avail_default = true;
-  public static boolean m_is_find_up_avail_default = true;
-  public static boolean m_is_find_down_avail_default = true;
-  public static boolean m_is_edit_filter_avail_default = true;
-  public static boolean m_is_collect_exp_avail_default = true;
-  public static boolean m_exit_as_last_win_closed = true;
-  public static boolean m_dispose_frame_as_win_closed = true;
-  // these are values for the IPC session
-  public boolean m_is_open_exp_avail_session = m_is_open_exp_avail_default;
-  public boolean m_is_aggregate_exp_avail_session = m_is_aggregate_exp_avail_default;
-  public boolean m_is_compare_exp_avail_session = m_is_compare_exp_avail_default;
-  public boolean m_is_print_dsp_avail_session = m_is_print_dsp_avail_default;
-  public boolean m_is_new_win_avail_session = m_is_new_win_avail_default;
-  public boolean m_is_close_act_avail_session = m_is_close_act_avail_default;
-  public boolean m_is_exit_act_avail_session = m_is_exit_act_avail_default;
-  public boolean m_is_sel_present_avail_session = m_is_sel_present_avail_default;
-  public boolean m_is_sel_filter_avail_session = m_is_sel_filter_avail_default;
-  public boolean m_is_show_hide_obj_avail_session = m_is_show_hide_obj_avail_default;
-  public boolean m_is_tbar_color_avail_session = m_is_tbar_color_avail_default;
-  public boolean m_is_find_avail_session = m_is_find_avail_default;
-  public boolean m_is_find_up_avail_session = m_is_find_up_avail_default;
-  public boolean m_is_find_down_avail_session = m_is_find_down_avail_default;
-  public boolean m_is_edit_filter_avail_session = m_is_edit_filter_avail_default;
-  public boolean m_is_collect_exp_avail_session = m_is_collect_exp_avail_default;
   private static Analyzer instance;
   private static String[] arguments = null;
   private AnFrame anFrame = null;
@@ -137,27 +100,50 @@ public final class Analyzer {
   private String explanation_3_1 =
       AnLocale.getString(
           "gprofng GUI did not get a reply from the remote host. Please check that the"
-              + " specified remote host exists, and the specified Installation Path exists on the"
+              + " specified remote host exists, and the specified remote gprofng path exists on the"
               + " remote host.");
   private String explanation_3_2 =
       AnLocale.getString(
           "gprofng GUI did not get a reply from the remote host. Please check that the"
-              + " specified Installation Path exists on the remote host.");
+              + " specified remote gprofng path exists on the remote host.");
   private String explanation_9 =
       AnLocale.getString(
           "gprofng GUI version does not match version on the remote host as specified by"
-              + " the Installation Path.");
+              + " the remote gprofng path.");
   // Connection protocol version
   private static String IPC_PROTOCOL = IPCProtocol.IPC_PROTOCOL_STR;
   private final String ipc_protocol = IPC_PROTOCOL;
 
-  private static final String JSSH_jar = "/share/gprofng-gui/JSSH3.jar";
-  private static final String DisplayAppName = "gp-display-text";
+  public static final String DisplayAppName = "gp-display-text";
   private static final String CollectAppName = "gp-collect-app";
   private static final String KernelAppName = "gp-collect-kernel";
 
   public Analyzer() {
     instance = this;
+    // Find installed directory fdhome & nbhome
+    cls_loader = Analyzer.class.getClassLoader();
+    fdhome = AnUtility.findResourceHome(cls_loader, "org/gprofng/mpmt/Analyzer.class");
+
+    // Method AnUtility.findResourceHome()returns wrong path on Windows
+    // System.err.println("AnUtility.findResourceHome returned fdhome = " + fdhome);
+    os_name = System.getProperty("os.name");
+    if (os_name.contains("Windows")) {
+      remoteShell = "ssh";
+      if (fdhome.length() > 2 && fdhome.charAt(2) == ':'
+          && fdhome.charAt(0) == '/') {
+        fdhome = fdhome.substring(1);
+      }
+    }
+
+    licpath = System.getProperty("analyzer.licpath", fdhome + "/lib/serial.dat");
+
+    String s = AnUtility.getenv("GPROFNG_DEBUG");
+    if (s != null) {
+      try {
+        AnUtility.debugFlags = Integer.parseInt(s);
+      } catch (NumberFormatException e) {
+      }
+    }
     IPC_session = new IPC(this);
   }
 
@@ -174,34 +160,6 @@ public final class Analyzer {
     }
   }
 
-  public static boolean initPath(final boolean in_netbeans) {
-    // Analyzer.in_netbeans = in_netbeans;
-
-    // Done initialize
-    if (cls_loader != null) {
-      return in_netbeans; // Analyzer.in_netbeans;
-    }
-    // Find installed directory fdhome & nbhome
-    cls_loader = Analyzer.class.getClassLoader();
-    fdhome = AnUtility.findResourceHome(cls_loader, "org/gprofng/mpmt/Analyzer.class");
-
-    // Method AnUtility.findResourceHome()returns wrong path on Windows
-    // System.err.println("AnUtility.findResourceHome returned fdhome = " + fdhome);
-    if (fdhome.charAt(2) == ':') {
-      if (fdhome.charAt(0) == '/') {
-        String os_name = System.getProperty("os.name");
-        if (os_name.contains("Windows")) {
-          fdhome = fdhome.substring(1);
-          // System.err.println("Corrected for Windows fdhome = " + fdhome);
-        }
-      }
-    }
-
-    licpath = System.getProperty("analyzer.licpath", fdhome + "/lib/serial.dat");
-
-    return in_netbeans; // Analyzer.in_netbeans;
-  }
-
   /**
    * @return the workingDirectory
    */
@@ -224,10 +182,14 @@ public final class Analyzer {
    * @param workingDirectory the workingDirectory to set
    */
   public void initWorkingDirectory() {
-    String wd = getCurrentDirectory(); // IPC call!
-    //        System.out.println("initWorkingDirectory: " + wd);
-    if (wd != null) {
-      this.workingDirectory = wd;
+    if (IPC_session == null) {
+      workingDirectory = System.getProperty("user.dir", ".");
+    } else {
+      String wd = getCurrentDirectory(); // IPC call!
+      if (wd == null) {
+        wd = System.getProperty("user.dir", ".");
+      }
+      workingDirectory = wd;
     }
   }
 
@@ -236,11 +198,10 @@ public final class Analyzer {
    *     "localhost"
    */
   public String getHost() {
-    String host = "localhost";
-    if (remoteConnection != null) {
-      host = remoteHost;
+    if (remoteHost != null) {
+      return remoteHost;
     }
-    return host;
+    return "localhost";
   }
 
   /**
@@ -279,18 +240,6 @@ public final class Analyzer {
    * @return returns whether kernel profiling is enabled
    */
   public boolean isKernelProfilingEnabled() {
-    if (kernelProfilingEnabled == null) {
-      if (IPC_started) {
-        if (er_print != null) {
-          kernelProfilingEnabled = false; // not enabled
-          String er_kernel = er_print.replace("/gp-display-text", "/er_kernel");
-          AnFile ek = new AnFile(er_kernel);
-          if (ek.exists()) {
-            kernelProfilingEnabled = true; // enabled
-          }
-        }
-      }
-    }
     return kernelProfilingEnabled;
   }
 
@@ -376,16 +325,7 @@ public final class Analyzer {
       er_print = AnUtility.getenv("SP_ANALYZER_ER_PRINT");
     }
     if (er_print == null || er_print.equals(emptyString)) {
-      er_print = null;
-      if (UserPref.gprofngdir != null) {
-        er_print = get_exe_name(UserPref.gprofngdir + "/" + DisplayAppName);
-      }
-      if (er_print == null && fdhome != null) {
-	er_print = get_exe_name(fdhome + "/bin/" + DisplayAppName);
-      }
-      if (er_print == null) {
-	er_print = "" + DisplayAppName;
-      }
+      er_print = getPathToApp(DisplayAppName);
     } else {
       IPCLogger.logTrace("\n" + "analyzer: SP_ANALYZER_ER_PRINT='" + er_print + "'");
       if (remoteConnection != null) {
@@ -432,17 +372,24 @@ public final class Analyzer {
    * @param host
    * @param name
    * @param p
+   * @param connectCommand
    * @param path
+   * @return 
    */
   public String createNewIPC(
       ConnectionDialog cc,
       String host,
       String name,
       char[] p,
-      String path,
-      ConnectionProperties connectionProperties) {
-    AnUtility.checkIPCOnWrongThread(false);
-    kernelProfilingEnabled = null;
+      String connectCommand,
+      String path) {
+    kernelProfilingEnabled = false;
+    AnLog.log("host: " + host);
+    AnLog.log("name: " + name);
+    AnLog.log("p: " + (p == null ? "NULL" : String.valueOf(p)));
+    AnLog.log("connectCommand: " + connectCommand);
+    AnLog.log("path: " + path);
+
     fireConnectionStatus(AnChangeEvent.Type.REMOTE_CONNECTION_CHANGING);
     stopConnectionManager();
     // Destroy old IPC session
@@ -450,7 +397,6 @@ public final class Analyzer {
       IPC new_IPC_session = IPC_session;
       IPC_session = old_IPC_session;
       setIPCStarted(old_IPC_status);
-      // win.QUIT();
       old_IPC_session.destroyIPCProc();
       IPC_session = new_IPC_session;
     }
@@ -458,85 +404,66 @@ public final class Analyzer {
     old_IPC_session = IPC_session;
     old_IPC_status = IPC_started;
     IPC newIPC = new IPC(this);
-    String str_gp_display_text = "gp-display-text";
-    String path_to_er_print = str_gp_display_text;
+    String path_to_er_print = DisplayAppName;
     String l_fdhome = emptyString;
     if (null != path) {
       l_fdhome = path.trim();
       if (l_fdhome.length() > 0) {
         if (!l_fdhome.equals(path_to_er_print)) {
-          if (l_fdhome.endsWith("/" + str_gp_display_text)) {
+          if (l_fdhome.endsWith("/" + DisplayAppName)) {
             path_to_er_print = l_fdhome;
+          } else if (l_fdhome.endsWith("/bin/")) {
+            path_to_er_print = l_fdhome + DisplayAppName;
+          } else if (l_fdhome.endsWith("/bin")) {
+            path_to_er_print = l_fdhome + "/" + DisplayAppName;
+          } else if (l_fdhome.endsWith("/")) {
+            path_to_er_print = l_fdhome + "bin/" + DisplayAppName;
           } else {
-            if (l_fdhome.endsWith("/bin") || l_fdhome.endsWith("/bin/")) {
-              path_to_er_print = l_fdhome + "/" + str_gp_display_text;
-            } else {
-              path_to_er_print = l_fdhome + "/bin/" + str_gp_display_text;
-            }
+            path_to_er_print = l_fdhome + "/bin/" + DisplayAppName;
           }
         }
       }
-      System.out.println("path: " + path);
+      AnLog.log("path: " + path);
     }
-    System.out.println("l_fdhome: " + l_fdhome);
-    System.out.println("str_gp_display_text: " + str_gp_display_text);
-    String str_collect = "gp-collect-app";
-    int i = path_to_er_print.lastIndexOf(str_gp_display_text);
-    String path_to_collect = path_to_er_print.substring(0, i) + str_collect;
+    AnLog.log("l_fdhome: " + l_fdhome);
+    AnLog.log("str_gp_display_text: " + DisplayAppName);
+    int i = path_to_er_print.lastIndexOf(DisplayAppName);
+    String path_to_collect = path_to_er_print.substring(0, i) + CollectAppName;
     String er_printCmd = path_to_er_print;
     String rc = null;
     String emsg = null;
     // Authentication
-    String ra = emptyString; // default - password
-    if (null != connectionProperties) {
-      ra = Authentication.toKeyString(connectionProperties.getAuthentications());
-      if (null == ra) {
-        ra = emptyString;
-      } else {
-        ra = " -a " + ra;
-      }
-    }
     String rh = host;
     if (rh != null) {
       rh = rh.trim(); // remove spaces
     }
     // Empty host name is not accepted
-    if ((rh == null) || (rh.equals(emptyString))) {
-      return (known_problem_0);
+    if (rh == null || rh.length() == 0) {
+      return AnLocale.getString("Empty host name is not valid.");
     }
-    if ((!rh.equals(emptyString)) && (!rh.equals("localhost"))) {
+    if (rh.length() > 0 && !rh.equals("localhost")) {
       // Add user name if it is not empty
-      if ((name != null)) {
+      if (name != null) {
         name = name.trim(); // remove spaces
-        if (!name.equals(emptyString)) {
+        if (name.length() > 0) {
           rh = name + "@" + rh;
         }
       }
-      String rs = AnUtility.getenv("SP_ANALYZER_REMOTE_SHELL");
-      if (rs != null) { // Special way to login
-        rc = remoteShell + " " + rh;
-      } else {
-        rc = remoteShell + ra + " " + rh;
-      }
-      er_printCmd = rc + " " + path_to_er_print;
-    }
-    String cmode = AnUtility.getenv("SP_ANALYZER_CONFIG_MODE");
-    if ((cmode != null) && (cmode.equals("R"))) {
-      er_printCmd = er_printCmd + " -RIPC";
-    } else {
-      er_printCmd = er_printCmd + " -IPC";
+      remoteConnectCommand = connectCommand + " " + rh;
+      er_printCmd = remoteConnectCommand + " " + er_printCmd;
     }
+    rc = er_printCmd;
+    er_printCmd = er_printCmd + " -IPC";
     String tracelevel = null; // AnUtility.getenv("SP_ER_PRINT_TRACE_LEVEL");
     if (tracelevel != null) {
-      String er_printCmd_extn = " -E SP_ER_PRINT_TRACE_LEVEL=" + tracelevel;
-      er_printCmd = er_printCmd + er_printCmd_extn;
+      er_printCmd = er_printCmd + " -E SP_ER_PRINT_TRACE_LEVEL=" + tracelevel;
     }
     if (ipc_protocol != null) {
-      String er_printCmd_extn = " -E SP_IPC_PROTOCOL=" + ipc_protocol;
-      er_printCmd = er_printCmd + er_printCmd_extn;
+      er_printCmd = er_printCmd + " -E SP_IPC_PROTOCOL=" + ipc_protocol;
     }
     // Initialize new IPC connection - start gp-display-text
     try {
+      AnLog.log("Start connection:\n" + er_printCmd);
       newIPC.init(er_printCmd, false);
       sendP(newIPC, p, cc);
       er_print = path_to_er_print;
@@ -547,7 +474,6 @@ public final class Analyzer {
     }
     newIPC.getIPCReader().runThread(); // TEMPORARY FOR DEBUG
 
-    AnWindow win = AnWindow.getInstance();
     if (IPC_started) { // see newinit()
       // AnFrame if fully initialized
       try {
@@ -569,7 +495,6 @@ public final class Analyzer {
         // Could not establish new connection
         IPC_session = old_IPC_session;
         setIPCStarted(old_IPC_status);
-        // win.QUIT();
         newIPC.destroyIPCProc();
         fireConnectionStatus(AnChangeEvent.Type.REMOTE_CONNECTION_CANCELLED_OR_FAILED);
         return (emsg);
@@ -669,7 +594,6 @@ public final class Analyzer {
         // Restore old IPC_session
         IPC_session = old_IPC_session;
         setIPCStarted(old_IPC_status);
-        // win.QUIT();
         newIPC.destroyIPCProc();
         fireConnectionStatus(AnChangeEvent.Type.REMOTE_CONNECTION_CANCELLED_OR_FAILED);
         return (emsg);
@@ -687,7 +611,6 @@ public final class Analyzer {
           fireConnectionStatus(AnChangeEvent.Type.REMOTE_CONNECTION_CANCELLED_OR_FAILED);
           return AnLocale.getString("Initialization failed");
         }
-        win = AnWindow.getInstance();
         if (cc.cancelRequest) {
           emsg = AnLocale.getString("Connection canceled");
         }
@@ -698,7 +621,6 @@ public final class Analyzer {
         // Could not establish new connection
         IPC_session = old_IPC_session;
         setIPCStarted(old_IPC_status);
-        // win.QUIT();
         newIPC.destroyIPCProc();
         fireConnectionStatus(AnChangeEvent.Type.REMOTE_CONNECTION_CANCELLED_OR_FAILED);
         return (emsg);
@@ -733,7 +655,6 @@ public final class Analyzer {
     Thread createCollectorDialog =
         new Thread(
             new Runnable() {
-              // @Override
               @Override
               public void run() {
                 AnWindow.getInstance().resetProfileDialogs();
@@ -741,7 +662,6 @@ public final class Analyzer {
               }
             });
     createCollectorDialog.run();
-    AnUtility.checkIPCOnWrongThread(false);
     return null;
   }
 
@@ -803,12 +723,12 @@ public final class Analyzer {
             + ts); // DEBUG
     cc.updateConnectionStatus(status1);
     if ((null != pass) && (pass.length > 0)) {
-      // this hangs if jssh+er_print do not send anything
       int c = 190; // timeout 19 seconds
       // Don't read - another thread (IPCReader) is already reading it.
       while (c-- > 0) {
         Thread.sleep(100);
         ask = ipc.getIPCReader().getUnknownInput();
+    AnLog.log(String.format("connectionID=%d Timestamp=%ld ask=%s;\n", ts));
         if (ask.contains(pattern2)) {
           break;
         }
@@ -874,9 +794,6 @@ public final class Analyzer {
           cc.updateConnectionStatus(known_problem_6);
           throw new Exception(known_problem_6);
         }
-        // if (ask.length() > 100000) {
-        //    break; // Why so many? Something wrong.
-        // }
       }
       if (!skip_pass) { // got request for the password
         ts = System.currentTimeMillis();
@@ -1233,8 +1150,6 @@ public final class Analyzer {
     }
     long totalBytes = IPC_session.getIPCReader().getTotalReceivedBytes();
     long totalMsg = IPC_session.getIPCReader().getTotalReceivedMessages();
-    // System.err.println("Connection performance (SYNC): Total bytes 1=" + totalBytes + " bytes.
-    // Total messages 1=" + totalMsg + " msg.");  // DEBUG
     long t1 = System.currentTimeMillis();
     int max = 100;
     Integer k = new Integer(runTest);
@@ -1376,17 +1291,34 @@ public final class Analyzer {
     sendPCollect(collector, p, cc);
   }
 
+  private String getPathToApp(String appName) {
+    String path;
+    if (UserPref.gprofngdir != null) {
+      path = UserPref.gprofngdir + "/" + appName;
+      if (Files.exists(Paths.get(path))) {
+        return path;
+      }
+    }
+    if (UserPref.binDirFromCommandLine != null) {
+      path = UserPref.binDirFromCommandLine + "/" + appName;
+      if (Files.exists(Paths.get(path))) {
+        return path;
+      }
+    }
+    if (fdhome != null) {
+      path = fdhome + "/bin/" + appName;
+      if (Files.exists(Paths.get(path))) {
+        return path;
+      }
+    }
+    return appName;
+  }
+
   /** Get path to local or remote collect */
   public String getPathToCollect() {
     if (!isRemote()) {
-      String collectPath = null; // AnUtility.getenv("SP_ANALYZER_COLLECT");
-      if (collectPath == null || collectPath.length() == 0) {
-        collectPath = UserPref.binDirFromCommandLine != null ?
-          UserPref.binDirFromCommandLine + "/" + CollectAppName : CollectAppName;
-        AnLog.log("analyzer: collect=" + collectPath + "\n");
-      } else {
-        AnLog.log("analyzer: SP_ANALYZER_COLLECT=" + collectPath + "\n"); // DEBUG
-      }
+      String collectPath = getPathToApp(CollectAppName);
+      AnLog.log("analyzer: COLLECT=" + collectPath + "\n");
       return collectPath;
     }
     return last_CC_collect;
@@ -1398,11 +1330,7 @@ public final class Analyzer {
    * @return
    */
   public String getPathToCollectKernel() {
-    String cmd = getPathToCollect();
-    if (cmd.endsWith(CollectAppName)) {
-      cmd = cmd.substring(0, cmd.length() - CollectAppName.length()) + KernelAppName;
-    }
-    return cmd;
+    return getPathToApp(KernelAppName);
   }
 
   /**
@@ -1733,41 +1661,8 @@ public final class Analyzer {
     //     remoteHost = AnUtility.getenv("SP_ANALYZER_REMOTE_HOST");
     // }
     String specialRemoteShell = AnUtility.getenv("SP_ANALYZER_REMOTE_SHELL");
-    if (specialRemoteShell != null && !specialRemoteShell.equals(emptyString)) {
+    if (specialRemoteShell != null && specialRemoteShell.length() > 0) {
       remoteShell = specialRemoteShell;
-    } else {
-      if (fdhome.charAt(2) == ':') {
-        if (fdhome.charAt(0) == '/') {
-          String os_name = System.getProperty("os.name");
-          if (os_name.contains("Windows")) {
-            fdhome = fdhome.substring(1);
-            AnLog.log("analyzer: Corrected path for Windows: fdhome = " + fdhome + "\n");
-          }
-        }
-      }
-      // if ( ("SunOS".equals(os_name)) || ("Linux".equals(os_name)) ) {
-      //   remoteShell = fdhome + "/../../../bin/jssh";
-      // } else {
-      // remoteShell = "java -Djava.awt.headless=true -cp " + fdhome +
-      // "/../../../lib/analyzer/lib/jssh/lib/jssh.jar jssh.Main ";
-      // remoteShell = "java -cp " + fdhome + "/../../../lib/analyzer/lib/jssh/lib/jssh.jar
-      // jssh.Main ";
-      // }
-      String jar_name = fdhome + JSSH_jar;
-      // Escape spaces
-      if (jar_name.contains("%20")) {
-        jar_name = jar_name.replace("%20", " ");
-      }
-      if (jar_name.contains(" ")) {
-        jar_name = emptyString + '"' + jar_name + '"';
-      }
-      // System.err.println("Java home: "+Analyzer.jvm_home);
-      // String java = emptyString + Analyzer.jvm_home + "/bin/java";
-      // System.err.println("Java : "+java);
-      // remoteShell = emptyString + java + " -jar " + jar_name;
-      remoteShell = "java -jar " + jar_name;
-      // System.err.println("remoteShell = " + remoteShell);
-      AnLog.log("analyzer: remoteShell = " + remoteShell + "\n");
     }
     if (remoteHost != null && !remoteHost.equals(emptyString)) {
       // System.err.println("analyzer: SP_ANALYZER_REMOTE_HOST `" + remoteHost + "'");
@@ -1851,29 +1746,14 @@ public final class Analyzer {
     licsts = license_info[0];
     fdversion = license_info[1];
 
-    String oldVersion = "Sun Analyzer";
-    String temporaryNewVersion = getAnalyzerReleaseName();
-    if ((null != fdversion) && (fdversion.startsWith(oldVersion))) {
-      int c1 = oldVersion.length();
-      fdversion = temporaryNewVersion + fdversion.substring(c1);
-    }
-
-    if (licsts.equals("ERROR")) {
-      emsg =
-          AnLocale.getString("License Path: ")
-              + licpath
-              + "\n"
-              + AnLocale.getString("Error: ")
-              + fdversion;
+    if (licsts.equals("ERROR") || licsts.equals("FATAL")) {
+      emsg = String.format(AnLocale.getString("License Path: %s\nError: %s"),
+          licpath, fdversion);
       System.err.println(emsg);
       System.exit(1);
-    } else if (licsts.equals("WARN") || licsts.equals("FATAL")) {
-      emsg =
-          AnLocale.getString("License Path: ")
-              + licpath
-              + "\n"
-              + AnLocale.getString("Warning: ")
-              + fdversion;
+    } else if (licsts.equals("WARN")) {
+      emsg = String.format(AnLocale.getString("License Path: %s\nWarning: %s"),
+          licpath, fdversion);
       System.err.println(emsg);
     }
     if (IPC_started) {
@@ -1943,10 +1823,6 @@ public final class Analyzer {
                           UserPref.getHomeConfigurationDirPath()
                               + "/"
                               + UserPref.getDefaultConfigurationName();
-                      //                                if (!new File(configurationPath).exists()) {
-                      //                                    configurationPath =
-                      // UserPref.getInstance().getLastClosedExpConfPath();
-                      //                                }
                     }
                   }
                 }
@@ -1982,8 +1858,6 @@ public final class Analyzer {
                   Dimension d1 = new Dimension(d0.width + 1, d0.height + 1);
                   anFrame.setSize(d1);
                   anFrame.setSize(d0);
-                  // System.out.println("Resized: old size=("+d0.width+","+d0.height+") new
-                  // size=("+d1.width+","+d1.height+")");
                 }
                 // Show pop-up
                 // String msg = "The Analyzer is now running in remote mode. You can connect to a
