@@ -1,4 +1,4 @@
-/* Copyright (C) 2022-2024 Free Software Foundation
+/* Copyright (C) 2022-2025 Free Software Foundation
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -39,7 +39,6 @@ import javax.swing.JButton;
 import javax.swing.JComboBox;
 import javax.swing.JFileChooser;
 import javax.swing.JLabel;
-import javax.swing.JPasswordField;
 import javax.swing.JProgressBar;
 import javax.swing.JTextArea;
 import javax.swing.JTextField;
@@ -52,11 +51,9 @@ public final class ConnectionDialog extends AnDialog implements ItemListener {
   private static String startDir = null;
   private JComboBox hostNameComboBox;
   private JTextField file;
-  private JPasswordField passwordField;
   private JTextField usernameTextField;
   private JTextField solstudioPathTextField;
-  private JTextField authenticationTextField;
-  private JButton authenticationManageButton;
+  private JTextField connectCommandTextField;
   private JLabel statusValueLabel;
   private JTextArea messageTextArea;
   private AnWindow m_window;
@@ -76,20 +73,12 @@ public final class ConnectionDialog extends AnDialog implements ItemListener {
   private List<Authentication> authentications = null;
 
   // Constructor
-  public ConnectionDialog(
-      final AnWindow window, final Frame frame, StatusLabelValueHandle connectedStatusHandle) {
-    super(
-        window,
-        frame,
-        AnLocale.getString("Connect to Remote Host"),
-        false,
-        null,
-        null,
-        help_id,
-        false);
+  public ConnectionDialog(final AnWindow window, final Frame frame,
+      StatusLabelValueHandle connectedStatusHandle) {
+    super(window, frame, AnLocale.getString("Connect to Remote Host"), false,
+        null, null, help_id, false);
     this.connectedStatusHandle = connectedStatusHandle;
     m_window = window;
-    //        active_id = window.getWindowID();
     initComponents();
     updateStatus();
   }
@@ -99,7 +88,6 @@ public final class ConnectionDialog extends AnDialog implements ItemListener {
     getContentPane().setBackground(AnEnvironment.DEFAULT_PANEL_BACKGROUND);
     connectionPanel = new ConnectionPanel(this);
     hostNameComboBox = connectionPanel.getHostNameComboBox();
-    // hostNameComboBox.addItem(local_host);
     String os_name = Analyzer.getInstance().os_name;
     String lh = local_host;
     if (null != os_name) {
@@ -108,21 +96,26 @@ public final class ConnectionDialog extends AnDialog implements ItemListener {
       }
     }
     hostNameComboBox.addItem(lh);
+    int count = 0;
     for (StringPickListElement hostElement :
         UserPref.getInstance().getHostNamePicklist().getStringElements()) {
       hostNameComboBox.addItem(hostElement.getString());
+      count = count + 1;
+    }
+    if (count > 0) {
+      hostNameComboBox.setSelectedIndex(1);
+    }    
+    else {
+      hostNameComboBox.setSelectedIndex(0);
     }
-    hostNameComboBox.setSelectedIndex(0);
     hostNameComboBox.setEditable(true);
     ((JTextField) hostNameComboBox.getEditor().getEditorComponent())
         .getDocument()
         .addDocumentListener(comboboxDocumentListener = new ComboBoxDocumentListener());
 
     usernameTextField = connectionPanel.getUserNameTextField();
-    passwordField = connectionPanel.getPasswordField();
     solstudioPathTextField = connectionPanel.getSolstudioPathTextField();
-    authenticationTextField = connectionPanel.getAuthenticationTextField();
-    authenticationManageButton = connectionPanel.getAuthenticationManageButton();
+    connectCommandTextField = connectionPanel.getConnectCommandTextField();
     statusValueLabel = connectionPanel.getConnectionStatusValueLabel();
     statusValueLabel.setForeground(Color.BLACK);
     messageTextArea = connectionPanel.getMessageTextArea();
@@ -137,16 +130,13 @@ public final class ConnectionDialog extends AnDialog implements ItemListener {
     }
     statusValueLabel.setText(status);
     progressBar = connectionPanel.getConnectionProgressBar();
-    //        progressBar.setVisible(false);
-    //        pack();
+    connectCommandTextField.setText(an.remoteShell);
 
     // Change buttons
     JButton[] buttons = getDefaultButtons();
     if (buttons.length > 2) {
       was_ok = buttons[0];
       was_ok.setText(AnLocale.getString("Connect"));
-      //            was_ok.setMnemonic(AnLocale.getString('n',
-      // "RemoteConnectDialogConnectButtonMN"));
       was_ok.setEnabled(true);
       close_on_enter = false;
       was_apply = buttons[1];
@@ -171,101 +161,55 @@ public final class ConnectionDialog extends AnDialog implements ItemListener {
 
   protected void setAuthentications(List<Authentication> authentications) {
     this.authentications = authentications;
-
-    passwordField.setEnabled(false);
-    passwordField.setText("");
-    if (authentications != null) {
-      authenticationTextField.setText(Authentication.toString(authentications));
-      authenticationManageButton.setEnabled(true);
-      for (Authentication auth : authentications) {
-        if (auth.isOn() && auth.getType() == Authentication.Type.PASSWORD) {
-          passwordField.setEnabled(true);
-          break;
-        }
-      }
-    } else {
-      authenticationTextField.setText("");
-      authenticationManageButton.setEnabled(false);
-      passwordField.setEnabled(false);
-    }
   }
 
   class ComboBoxDocumentListener implements DocumentListener {
 
-    //        @Override
     @Override
     public void changedUpdate(DocumentEvent e) {
       updateStatus();
     }
 
-    //        @Override
     @Override
     public void insertUpdate(DocumentEvent e) {
       updateStatus();
     }
 
-    //        @Override
     @Override
     public void removeUpdate(DocumentEvent e) {
       updateStatus();
     }
   }
 
-  private String getDefaultSolStudioPath() {
-    if (defaultSolstudioPath == null) {
-      String er_print = Analyzer.getInstance().er_print;
-      int index = er_print.lastIndexOf("bin");
-      if (index > 0) {
-        defaultSolstudioPath = er_print.substring(0, index - 1);
-      }
-    }
-    return defaultSolstudioPath;
-  }
-
   private void updateStatus() {
     AnUtility.checkIfOnAWTThread(true);
     String hostName = ((JTextField) hostNameComboBox.getEditor().getEditorComponent()).getText();
+    String ssh_cmd = window.getAnalyzer().remoteShell;
+    String install_dir = "/usr/bin";
+    String user_name = AnUtility.getenv("USER");
+    if (user_name == null) {
+      user_name = "";
+    }
+
     ConnectionProperties connectionProperties =
         UserPref.getInstance().getConnectionPropertiesMap().get(hostName);
-    String empty = "";
     if (connectionProperties != null) {
-      String path = connectionProperties.getPath();
-      if (path != null && path.length() > 0) {
-        solstudioPathTextField.setText(path);
-      } else {
-        solstudioPathTextField.setText(empty);
+      String s = connectionProperties.getConnectCommand();
+      if (s != null && s.length() > 0) {
+        ssh_cmd = s;
       }
-
-      String userName = connectionProperties.getUserName();
-      if (userName != null && userName.length() > 0) {
-        usernameTextField.setText(userName);
-      } else {
-        usernameTextField.setText(empty);
+      s = connectionProperties.getPath();
+      if (s != null && s.length() > 0) {
+        install_dir = s;
       }
-
-      if (hostName.equals(local_host) || hostName.length() == 0) {
-        setAuthentications(null);
-      } else {
-        setAuthentications(connectionProperties.getAuthentications());
-      }
-    } else {
-      String lastPath = solstudioPathTextField.getText();
-      if (hostName.equals(local_host) || hostName.length() == 0) {
-        solstudioPathTextField.setText(
-            getDefaultSolStudioPath()); // Default path (same as local path)
-        setAuthentications(null);
-      } else {
-        if (getDefaultSolStudioPath().equals(lastPath)) {
-          solstudioPathTextField.setText(empty);
-        }
-        setAuthentications(UserPref.getDefaultAuthentications());
+      s = connectionProperties.getUserName();
+      if (s != null && s.length() > 0) {
+        user_name = s;
       }
     }
-    if (hostName.equals(local_host)) {
-      connectionPanel.setLoginFieldsEnabled(false);
-    } else {
-      connectionPanel.setLoginFieldsEnabled(true);
-    }
+    connectionPanel.setLoginFieldsEnabled(!hostName.equals(local_host));
+    connectCommandTextField.setText(ssh_cmd);
+    solstudioPathTextField.setText(install_dir);
   }
 
   // Set visible
@@ -284,15 +228,7 @@ public final class ConnectionDialog extends AnDialog implements ItemListener {
   /*
    * Connect to remote host
    */
-  public String connectToRemoteHost(ConnectionProperties connectionProperties, int timeout) {
-    //        if (connectionProperties != null) {
-    //            System.out.println("User Name:           " + connectionProperties.getUserName());
-    //            System.out.println("Path:                " + connectionProperties.getPath());
-    //            String authenticationMethodKeys =
-    // Authentication.toKeyString(connectionProperties.getAuthentications());
-    //            System.out.println("Authentication Keys: " + authenticationMethodKeys);
-    //        }
-
+  public String connectToRemoteHost(int timeout) {
     try {
       if (!isVisible()) {
         setVisible(true);
@@ -309,32 +245,42 @@ public final class ConnectionDialog extends AnDialog implements ItemListener {
       if (un != null) {
         un = un.trim();
       }
+      char[] p = null;
+      /*
       char[] p = passwordField.getPassword();
       if (p.length <= 0) {
         p = null;
       }
-      String path = solstudioPathTextField.getText();
-      if (path != null) {
-        path = path.trim();
+      */
+      String connectCommand = connectCommandTextField.getText().trim();
+      if (connectCommand.length() < 1) {
+        return (AnLocale.getString("Error: connection command is not specified."));
       }
-      if ((path == null) || (path.length() < 1)) {
-        return (AnLocale.getString("Error: Installation Path is not specified."));
+      connectCommand += " -o PasswordAuthentication=no " + 
+          "-o UserKnownHostsFile=/dev/null -o StrictHostKeyChecking=no";
+      String path = solstudioPathTextField.getText().trim();
+      if (path.length() < 1) {
+        return (AnLocale.getString("Error: remote gprofng path is not specified."));
       }
-      if (!path.endsWith("gp-display-text")) {
-        if (path.endsWith("bin") || path.endsWith("bin/")) {
-          path = path + "/gp-display-text";
+      String appName = Analyzer.DisplayAppName;
+      if (!path.endsWith("/" + appName)) {
+        if (path.endsWith("/bin")) {
+          path = path + "/" + appName;
+        } else if (path.endsWith("/bin/")) {
+          path = path + appName;
+        } else if (path.endsWith("/")) {
+          path = path + "bin/" + appName;
         } else {
-          path = path + "/bin/gp-display-text";
+          path = path + "/bin/" + appName;
         }
       }
-      String s = m_window.getAnalyzer().createNewIPC(this, host, un, p, path, connectionProperties);
-      // usernameTextField.setText("");
-      passwordField.setText("");
+      window.getAnalyzer().remoteGprofngPath = path.substring(0, path.length() - 16);
+      String s = m_window.getAnalyzer().createNewIPC(this, host, un, p, connectCommand, path);
       if (s != null) {
         return (s);
       }
     } catch (Exception e) {
-      return ("Exception during connectiing."); // Cancel
+      return ("Exception during connecting."); // Cancel
     }
     return null; // Successfully connected
   }
@@ -363,16 +309,21 @@ public final class ConnectionDialog extends AnDialog implements ItemListener {
       Map<String, ConnectionProperties> map = UserPref.getInstance().getConnectionPropertiesMap();
       connectionProperties =
           new ConnectionProperties(
-              solstudioPathTextField.getText(), usernameTextField.getText(), authentications);
+              solstudioPathTextField.getText(), connectCommandTextField.getText(), usernameTextField.getText(), authentications);
       map.put(hostName, connectionProperties);
-      UserPref.getInstance().getHostNamePicklist().addElement(hostName);
+      if (!(hostName.equals(local_host))) {
+          UserPref.getInstance().getHostNamePicklist().addElement(hostName);
+      }
+      // System.out.println("Connect to host: " + hostName);
       if (comboboxDocumentListener != null) {
         ((JTextField) hostNameComboBox.getEditor().getEditorComponent())
             .getDocument()
             .removeDocumentListener(comboboxDocumentListener);
       }
       hostNameComboBox.removeAllItems();
-      hostNameComboBox.addItem(local_host);
+      if (Analyzer.getInstance().os_name.contains("Linux")) {
+        hostNameComboBox.addItem(local_host);
+      }
       for (StringPickListElement hostElement :
           UserPref.getInstance().getHostNamePicklist().getStringElements()) {
         hostNameComboBox.addItem(hostElement.getString());
@@ -383,13 +334,10 @@ public final class ConnectionDialog extends AnDialog implements ItemListener {
             .getDocument()
             .addDocumentListener(comboboxDocumentListener);
       }
-      //            } else {
-      //                connectionProperties = null;
-      //            }
       connectionStarted();
       // Connect to remote host
       Thread worker =
-          new Thread(/*m_window.getAnalyzer().tgroup, */ "Connection_thread") {
+          new Thread("Connection_thread") {
 
             final int timeout = 3;
 
@@ -398,8 +346,8 @@ public final class ConnectionDialog extends AnDialog implements ItemListener {
               /* synchronized (AnVariable.worker_lock) */ {
                 threadConnector = this;
                 cancelRequest = false;
-                String res = connectToRemoteHost(connectionProperties, timeout);
-                if (true == cancelRequest) {
+                String res = connectToRemoteHost(timeout);
+                if (cancelRequest) {
                   cancelRequest = false;
                   res += ". Connection canceled";
                 }
@@ -408,17 +356,10 @@ public final class ConnectionDialog extends AnDialog implements ItemListener {
             }
           };
       worker.start();
-    }
-    if (cmd.equals(AnLocale.getString("Apply")) || cmd.equals(AnLocale.getString("Cancel"))) {
-      // TEMPORARY: Cancel
-      if (connectedStatusHandle
-          .get()
-          .equals(connecting) /* statusValueLabel.getText().equals(connecting) */) {
+    } else if (cmd.equals(AnLocale.getString("Apply"))
+        || cmd.equals(AnLocale.getString("Cancel"))) {
+      if (connectedStatusHandle.get().equals(connecting)) {
         cancelRequest = true;
-        // m_window.getAnalyzer().IPC_session = m_window.getAnalyzer().old_IPC_session;
-        // m_window.getAnalyzer().IPC_started = m_window.getAnalyzer().old_IPC_status;
-        // fld_status.setText(disconnected);
-        // progressBar.setIndeterminate(false);
         if (threadConnector != null) {
           try {
             threadConnector.interrupt();
@@ -426,6 +367,7 @@ public final class ConnectionDialog extends AnDialog implements ItemListener {
           } catch (Exception e) {
             // thread may already had gone
           }
+          threadConnector = null;
         }
       } else {
         setVisible(false);
@@ -433,15 +375,6 @@ public final class ConnectionDialog extends AnDialog implements ItemListener {
     }
   }
 
-  /**
-   * Gets host name
-   *
-   * @return String host name
-   */
-  //    public String getHost() {
-  //        String host = fld_host.getSelectedItem().toString();
-  //        return host;
-  //    }
   /** Sets buttons and fields states as they should be during connecting */
   private void connectionStarted() {
     Analyzer.getInstance().connectingToRemoteHost = true;
@@ -451,9 +384,10 @@ public final class ConnectionDialog extends AnDialog implements ItemListener {
     was_ok.setEnabled(false);
     was_apply.setEnabled(true);
     hostNameComboBox.setEditable(false);
-    passwordField.setEditable(false);
+    // passwordField.setEditable(false);
     usernameTextField.setEditable(false);
     solstudioPathTextField.setEditable(false);
+    connectCommandTextField.setEditable(false);
     // fld_status.setFont() // bold
     statusValueLabel.setForeground(Color.black);
     statusValueLabel.setText(connecting);
@@ -471,9 +405,10 @@ public final class ConnectionDialog extends AnDialog implements ItemListener {
     was_ok.setEnabled(true);
     was_apply.setEnabled(false);
     hostNameComboBox.setEditable(true);
-    passwordField.setEditable(true);
+    // passwordField.setEditable(true);
     usernameTextField.setEditable(true);
     solstudioPathTextField.setEditable(true);
+    connectCommandTextField.setEditable(true);
     if (result == null) {
       String hostName = hostNameComboBox.getSelectedItem().toString();
       //            if (hostName.equals(local_host)) {
