@@ -1,4 +1,4 @@
-/* Copyright (C) 2022-2024 Free Software Foundation
+/* Copyright (C) 2022-2025 Free Software Foundation
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -33,6 +33,9 @@ import java.awt.Font;
 import java.awt.Graphics;
 import java.awt.Graphics2D;
 import java.awt.Insets;
+import java.awt.Toolkit;
+import java.awt.datatransfer.Clipboard;
+import java.awt.datatransfer.StringSelection;
 import java.awt.event.ActionListener;
 import java.awt.event.FocusEvent;
 import java.awt.event.InputEvent;
@@ -48,10 +51,12 @@ import java.io.FileOutputStream;
 import java.io.FileReader;
 import java.io.IOException;
 import java.io.InputStream;
+import java.io.InputStreamReader;
 import java.io.OutputStream;
 import java.lang.ref.WeakReference;
 import java.net.URL;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
@@ -84,11 +89,16 @@ public final class AnUtility {
   public static final int WARNING_MSG = 2;
   public static final int PSTAT_MSG = 3;
   public static final int PWARN_MSG = 4;
+  public static final int SPACES_BETWEEN_COLUMNS = 3;
+  public static final String SPACE = " ";
+  public static final String EOL = "\n";
   // mime types for files
   public static final int MIME_ELF_EXECUTABLE = 0x7f454c46;
   public static final int MIME_JAVA_CLASS_FILE = 0xcafebabe;
   public static final int MIME_JAR_FILE = 0x504b0304;
   private static final int MIME_UNKNOWN_FILE_TYPE = 0x00000000;
+  public static final int MIME_DIRECTORY = 1;
+  public static final int MIME_EXECUTABLE = 2;
   public static final int MIME_CANNOT_READ_FILE = 0xFFFFFFFF;
   public static final Cursor norm_cursor = Cursor.getPredefinedCursor(Cursor.DEFAULT_CURSOR);
   public static final Cursor wait_cursor = Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR);
@@ -213,26 +223,38 @@ public final class AnUtility {
   private static AnThreadGroup threadGroup = new AnThreadGroup();
 
   public static int getMimeFormat(final File file) {
-    try {
-      if (!file.isFile()) {
-        return MIME_UNKNOWN_FILE_TYPE;
-      }
-      final DataInputStream dis =
-          new DataInputStream(new BufferedInputStream(new FileInputStream(file)));
-      int iMagicNumber = dis.readInt();
-      if (iMagicNumber == MIME_ELF_EXECUTABLE) { // reading elf header
-        dis.skipBytes(12);
-        final int elf_type = dis.readShort(); // check for elf executable
-        if (elf_type != 0x0002 && elf_type != 0x0200) // Not MSB or LSB elf executable
-        {
-          iMagicNumber = MIME_UNKNOWN_FILE_TYPE;
+    if (file.isDirectory()) {
+      return MIME_DIRECTORY;
+    }
+    if (file.canExecute()) {
+      if (Analyzer.getInstance().remoteConnection == null) {
+        try {
+          final DataInputStream dis = new DataInputStream(
+              new BufferedInputStream(new FileInputStream(file)));
+          int elf_type = 0;
+          int iMagicNumber = dis.readInt();
+          if (iMagicNumber == MIME_ELF_EXECUTABLE) { // reading elf header
+            dis.skipBytes(12);
+            elf_type = dis.readShort(); // check for elf executable
+          }
+          dis.close();
+          if (elf_type == 0x0002 || elf_type != 0x0200) { // MSB or LSB elf
+            return MIME_ELF_EXECUTABLE;
+          }
+        } catch (IOException e) {
+          return MIME_CANNOT_READ_FILE;
         }
       }
-      dis.close();
-      return iMagicNumber;
-    } catch (IOException e) {
-      return MIME_CANNOT_READ_FILE;
+      return MIME_EXECUTABLE;
     }
+    String nm = file.getName();
+    if (nm.endsWith(".class'")) {
+      return MIME_JAVA_CLASS_FILE;
+    }
+    if (nm.endsWith(".jar'")) {
+      return MIME_JAR_FILE;
+    }
+    return MIME_UNKNOWN_FILE_TYPE;
   }
 
   public static boolean isTarget(final File file) {
@@ -240,6 +262,34 @@ public final class AnUtility {
     return (type == MIME_ELF_EXECUTABLE || type == MIME_JAVA_CLASS_FILE || type == MIME_JAR_FILE);
   }
 
+  public static String getRemoteOutput(String cmd) {
+    String rc = Analyzer.getInstance().remoteConnectCommand;
+    ArrayList<String> args = new ArrayList<String>(
+        Arrays.asList(rc.split("\\s+")));
+    args.add(cmd);
+
+    ProcessBuilder processBuilder = new ProcessBuilder(args);
+    String lines = "";
+    try {
+      Process process = processBuilder.start();
+
+      // Read standard output
+      BufferedReader stdoutReader = new BufferedReader(
+          new InputStreamReader(process.getInputStream()));
+      for (;;) {
+        String line;
+        line = stdoutReader.readLine();
+        if (line == null) {
+          break;
+        }
+        lines += line + "\n";
+      }
+      process.waitFor();
+    } catch (IOException | InterruptedException ex) {
+    }
+    return lines;
+  }
+
   // General check box
   public static final class AnCheckBox extends JCheckBox {
 
@@ -1048,6 +1098,9 @@ public final class AnUtility {
   }
 
   private static void reportWrongThread(boolean shouldBe) {
+    if ((debugFlags & DEBUG_AWT_THR) == 0) {
+      return;
+    }
     Exception awtException = new Exception();
     StackTraceElement[] se = awtException.getStackTrace();
     StringBuilder s = new StringBuilder();
@@ -1058,8 +1111,8 @@ public final class AnUtility {
       s.append(se[i].toString() + "\n");
     }
     AnLog.log(s.toString());
-    System.err.println(
-        "analyzer: Invalid use of AWT thread. See log file: " + AnLog.getLogFilePath());
+    System.err.println("DEBUG: Invalid use of AWT thread. See log file: "
+        + AnLog.getLogFilePath());
   }
 
   public static void checkIPCOnWrongThread(boolean set) {
@@ -1082,6 +1135,22 @@ public final class AnUtility {
     return ret;
   }
 
+  /**
+   * Remove duplicate '/' characters in path:
+   * @param path
+   * @return
+   */
+  public static String clearPath(String path) {
+    StringBuilder sb = new StringBuilder();
+    for (int i = 0; i < path.length(); i++) {
+      if (path.charAt(i) == '/' && i > 0 && path.charAt(i - 1) == '/') {
+          continue;
+      }
+      sb.append(path.charAt(i));
+    }
+    return sb.toString();
+  }
+
   public static String getShortString(String string, int maxLength) {
     int len = string.length();
     if ((len - 1) <= maxLength) {
@@ -1130,6 +1199,14 @@ public final class AnUtility {
     }
   }
 
+  public static void copyToClipboard(String text) {
+    if (text != null && text.length() > 0) {
+      StringSelection data = new StringSelection(text);
+      Clipboard clipboard = Toolkit.getDefaultToolkit().getSystemClipboard();
+      clipboard.setContents(data, data);
+    }
+  }
+
   public static String keyStrokeToStringFormatted(KeyStroke keyStroke) {
     return "  (" + keyStrokeToString(keyStroke) + ")"; // NOI18N
   }
@@ -1239,4 +1316,7 @@ public final class AnUtility {
     s = s.replace("\"", "&quot;"); // NOI18N
     return s;
   }
+
+  public static int debugFlags = 0;
+  public static int DEBUG_AWT_THR = 1;
 }
