@@ -1,4 +1,4 @@
-/* Copyright (C) 2022-2024 Free Software Foundation
+/* Copyright (C) 2022-2025 Free Software Foundation
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ import javax.swing.JPanel;
 
 public class WelcomeInnerPanel extends javax.swing.JPanel {
 
-  private final int MOST_RECENT_EXP_LIST_SIZE = 8;
+  private final int MOST_RECENT_EXP_LIST_SIZE = 9;
   private static final Font font12 = new JLabel().getFont().deriveFont(12f);
   private static final Font bold12Font = font12.deriveFont(Font.BOLD);
   private static final Font plain12Font = font12.deriveFont(Font.PLAIN);
@@ -72,7 +72,9 @@ public class WelcomeInnerPanel extends javax.swing.JPanel {
   public WelcomeInnerPanel() {
     backgroundImageIcon =
         new ImageIcon(
-            getClass().getResource("/org/gprofng/mpmt/icons/welcomeBackgroundShadow.png"));
+//          getClass().getResource("/org/gprofng/mpmt/icons/welcomeScreenNoDivider.png"));			
+          getClass().getResource("/org/gprofng/mpmt/icons/welcomeBackgroundShadow.png"));
+//          getClass().getResource("/org/gprofng/mpmt/icons/welcomeAlternate.png"));
     initComponents();
     buildForeground();
     buildBackground();
@@ -89,7 +91,7 @@ public class WelcomeInnerPanel extends javax.swing.JPanel {
       connectButton.setEnabled(false);
     } else {
       setConnected(Analyzer.getInstance().isConnected());
-      connectButton.setEnabled(false);
+      connectButton.setEnabled(true);
     }
   }
 
@@ -193,7 +195,7 @@ public class WelcomeInnerPanel extends javax.swing.JPanel {
     gridBagConstraints.gridy = 1;
     gridBagConstraints.gridwidth = GridBagConstraints.REMAINDER;
     gridBagConstraints.anchor = GridBagConstraints.NORTHWEST;
-    gridBagConstraints.insets = new Insets(50, 75, 0, 0);
+    gridBagConstraints.insets = new Insets(20, 75, 0, 0);
     foregroundPanel.add(label3, gridBagConstraints);
 
     leftPanel = new JPanel();
@@ -205,7 +207,7 @@ public class WelcomeInnerPanel extends javax.swing.JPanel {
     gridBagConstraints.gridx = 0;
     gridBagConstraints.gridy = 2;
     gridBagConstraints.anchor = GridBagConstraints.NORTHWEST;
-    gridBagConstraints.insets = new Insets(16, 132, 0, 0);
+    gridBagConstraints.insets = new Insets(16, 122, 0, 0);
     foregroundPanel.add(leftPanel, gridBagConstraints);
 
     rightPanel = new JPanel();
@@ -257,11 +259,12 @@ public class WelcomeInnerPanel extends javax.swing.JPanel {
       openRecentExperimentButton = addActionButton(panel, gridy++, buttonText, buttonTT, null);
       if (Analyzer.getInstance().isConnected()) {
         recentExperimentsButtons = new ArrayList<WelcomeButton>();
-        for (ExperimentPickListElement experimentElement : recentExperiments) {
-          String displayName = AnUtility.basename(experimentElement.getPath());
+        for (ExperimentPickListElement experimentElement : recentExperiments) {  
+	  String displayName = AnUtility.basename(experimentElement.getPath());
           int length = displayName.length();
           if (length > 25) {
-            displayName = displayName.substring(0, 16) + "..." + displayName.substring(length - 7);
+		  // 16
+            displayName = displayName.substring(0, 54) + "..." + displayName.substring(length - 7);
           }
           recentExperimentsButtons.add(
               addExperimentButton(
@@ -278,6 +281,13 @@ public class WelcomeInnerPanel extends javax.swing.JPanel {
     compareExperimentsButton =
         addActionButton(panel, gridy++, action.getTextNoDots(), action.getTooltipText(), action);
 
+    addSpace(panel, 14, gridy++);
+	
+    addSectionTitleLabel(panel, AnLocale.getString("Remote"), gridy++);
+    action = AnWindow.getInstance().getConnectAction();
+    connectButton =
+        addActionButton(panel, gridy++, action.getTextNoDots(), action.getTooltipText(), action);
+
     addButtomFill(panel, gridy++);
     addRightFill(panel);
   }
@@ -286,12 +296,16 @@ public class WelcomeInnerPanel extends javax.swing.JPanel {
     AnAction action;
     int gridy = 0;
 
+    /*
     addSectionTitleLabel(panel, AnLocale.getString("Remote"), gridy++);
     action = AnWindow.getInstance().getConnectAction();
     connectButton =
         addActionButton(panel, gridy++, action.getTextNoDots(), action.getTooltipText(), action);
+    */
 
     addSpace(panel, 14, gridy++);
+
+    /*
     addSectionTitleLabel(panel, AnLocale.getString("Learn More"), gridy++);
 
     action = AnWindow.getInstance().getHelpAnalyzerAction();
@@ -300,7 +314,7 @@ public class WelcomeInnerPanel extends javax.swing.JPanel {
     addActionButton(panel, gridy++, action.getTextNoDots(), action.getTooltipText(), action);
     action = AnWindow.getInstance().getHelpInformationMapAction();
     addActionButton(panel, gridy++, action.getTextNoDots(), action.getTooltipText(), action);
-
+    */
     addButtomFill(panel, gridy++);
   }
 
